django-pj-budget
================

.. image:: https://badge.fury.io/py/django-pj-budget.png
    :target: https://badge.fury.io/py/django-pj-budget

.. image:: https://travis-ci.org/jokimies/django-pj-budget.png?branch=master
    :target: https://travis-ci.org/jokimies/django-pj-budget

In practice this is fork of `django-budget
<https://www.howtoforge.com/how-to-run-your-own-git-server-with-gitlabhq-on-ubuntu-14.04>`_
adapted to my needs

Cookiecutter Tools Used in Making This Package
----------------------------------------------

*  cookiecutter
*  cookiecutter-djangopackage
